IapResult class

Annotations

Constructors

IapResult({required PurchaseResponse responseCode, String? message})
const
IapResult.fromJson(Map<String, dynamic>? map)
factory

Properties

hashCode int
The hash code for this object.
no setteroverride
message String?
final
responseCode PurchaseResponse
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isSuccess() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override