OneStoreAuthClient class
MethodChannel을 사용하는 클래스는 모두 OneStoreMethodChannel을 상속받는다.
Constructors
Properties
- channel → MethodChannel
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
launchSignInFlow(
) → Future< SignInResult> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited