ProductDetail class

등록된 상품의 세부정보를 나타냅니다. 'com.gaa.sdk.iap.ProductDetail'

Annotations

Constructors

ProductDetail({required String productId, required ProductType productType, required String title, required String price, required String priceCurrencyCode, required String priceAmountMicros, required String subscriptionPeriod, String? subscriptionPeriodUnitCode, required String freeTrialPeriod, required String promotionPrice, required String promotionPriceMicros, required String promotionUsePeriod, required String paymentGracePeriod})
const
ProductDetail.fromJson(Map<String, dynamic> map)
factory

Properties

freeTrialPeriod String
무료 이용 기간
final
hashCode int
The hash code for this object.
no setteroverride
paymentGracePeriod String
결제 유예기간(일단위)
final
price String
상품의 가격
final
priceAmountMicros String
가격을 마이크로 단위로 환산. 1,000,000 마이크로 단위는 통화의 한 단위와 같습니다.
final
priceCurrencyCode String
가격에 대한 ISO 4217 통화 코드
final
productId String
상품의 아이디
final
productType ProductType
상품의 타입
final
promotionPrice String
프로모션 가격
final
promotionPriceMicros String
프로모션 가격을 마이크로 단위로 환산. 1,000,000 마이크로 단위는 통화의 한 단위와 같습니다.
final
promotionUsePeriod String
프로모션 적용 회차
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subscriptionPeriod String
구독 기간
final
subscriptionPeriodUnitCode String?
구독 기간 단위 코드
final
title String
상품의 이름
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override