PurchaseData class

구매한 정보를 나타내는 구조체입니다. 'com.gaa.sdk.iap.PurchaseData'

Annotations

Constructors

PurchaseData({required String orderId, required String productId, required String packageName, required int purchaseTime, required String purchaseToken, required PurchaseState purchaseState, required RecurringState recurringState, required int quantity, required bool isAcknowledged, String? developerPayload, required String originalJson, required String? signature})
const
PurchaseData.fromJson(Map<String, dynamic> map)
factory

Properties

developerPayload String?
acknowledge or consume 요청 때 지정했던 개발사의 페이로드 값
final
hashCode int
The hash code for this object.
no setteroverride
isAcknowledged bool
구매 확인(acknowledge)가 되었는지 여부
final
orderId String
구매에 대한 주문 아이디
final
originalJson String
JSON 형식의 원본 구매 데이터
final
packageName String
구매를 시작한 어플리케이션의 packageName
final
productId String
구매한 인앱 상품 아이디
final
purchaseState PurchaseState
구매 상태
final
purchaseTime int
구매가 성공한 시간 (milliseconds)
final
purchaseToken String
구매 데이터를 고유하게 식별하는 토큰
final
quantity int
상품의 수량
final
recurringState RecurringState
정기 결제의 상태
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
signature String?
originalJson 데이터의 서명된 파일 개발사에 발급된 공개키로 originalJsonsignature의 데이트를 가지고 구매 데이터의 유효성 검사를 진행할 수 있습니다.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override