SignInResult class
- Annotations
-
- @JsonSerializable.new()
- @AuthResponseConverter()
- @immutable
Constructors
- SignInResult({required AuthResponse code, required String message})
-
const
-
SignInResult.fromJson(Map<
String, dynamic> ? map) -
factory
Properties
- code → AuthResponse
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isSuccess(
) → bool -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited