AcknowledgeState enum
구매한 상품의 확인 값을 정의합니다. PurchaseData.isAcknowledged 통해 확인할 수 있습니다. 'PurchaseData.AcknowledgeState' 상수의 자세한 설명은 링크를 참조하세요.
Values
- notAcknowledged → const AcknowledgeState
- acknowledged → const AcknowledgeState
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AcknowledgeState> - A constant List of the values in this enum, in order of their declaration.