AuthResponse enum
Values
- ok → const AuthResponse
- userCanceled → const AuthResponse
- developerError → const AuthResponse
- error → const AuthResponse
- fail → const AuthResponse
- needLogin → const AuthResponse
- needUpdate → const AuthResponse
- errorInstall → const AuthResponse
- downloading → const AuthResponse
- installing → const AuthResponse
- emergencyError → const AuthResponse
- updateOrInstallFail → const AuthResponse
- serviceDisconnected → const AuthResponse
- featureNotSupported → const AuthResponse
- serviceTimeout → const AuthResponse
- clientNotEnabled → const AuthResponse
- signInFailed → const AuthResponse
- signInCanceled → const AuthResponse
- signInCurrentlyInProgress → const AuthResponse
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
AuthResponse> - A constant List of the values in this enum, in order of their declaration.