LicenseClient class
ALC 클라이언트
Constructors
- LicenseClient(String publicKey, [LicenseCallback? callback])
Properties
- callback ↔ LicenseCallback?
-
getter/setter pair
- channel → MethodChannel
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- publicKey → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> -
listen(
LicenseCallback callback) → void -
methodCallHandler(
MethodCall call) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
queryLicense(
) → Future< void> -
strictQueryLicense(
) → Future< void> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited