ProductDetailsResponse class
- Annotations
-
- @JsonSerializable.new()
- @immutable
Constructors
-
ProductDetailsResponse({required IapResult iapResult, required List<
ProductDetail> productDetailsList}) -
const
-
ProductDetailsResponse.fromJson(Map<
String, dynamic> map) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setteroverride
- iapResult → IapResult
-
final
-
productDetailsList
→ List<
ProductDetail> -
final
- responseCode → PurchaseResponse
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override