ProductType enum
상품의 타입을 정의합니다. 'PurchaseClient.ProductType' 상수의 자세한 설명은 링크를 참조하세요.
Values
- inapp → const ProductType
-
관리형 상품. 구매후 소비를 하지 않으면 재 구매할 수 없습니다.
- subs → const ProductType
-
구독 상품. 등록된 상품의 정해진 기간에 따라 자동 결제 및 연장되는 상품 타입입니다.
- all → const ProductType
-
WARNING! 상품 상세 조회
'PurchaseClient.queryProductDetails()'API에서만 사용할 수 있는 타입입니다. 상품 상세 정보를 요청할 때 한 번에 요청하기 위한 타입입니다.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProductType> - A constant List of the values in this enum, in order of their declaration.