ProrationMode enum
구독 상품의 업그레이드 또는 다운그레이드를 위한 비례 배분 모드입니다. Change the Subscription 'PurchaseFlowParams.ProrationMode' 상수의 자세한 설명은 링크를 참조하세요.
Values
- unknownSubscriptionUpgradeDowngradePolicy → const ProrationMode
- immediateWithTimeProration → const ProrationMode
- immediateAndChargeProratedPrice → const ProrationMode
- immediateWithoutProration → const ProrationMode
- deferred → const ProrationMode
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
ProrationMode> - A constant List of the values in this enum, in order of their declaration.