PurchaseResponse enum
PurchaseClient의 API 응답 상태를 정의합니다.
'PurchaseClient.ResponseCode'
상수의 자세한 설명은 링크를 참조하세요.
Values
- ok → const PurchaseResponse
- userCanceled → const PurchaseResponse
- developerError → const PurchaseResponse
- error → const PurchaseResponse
- itemAlreadyOwned → const PurchaseResponse
- itemNotOwned → const PurchaseResponse
- fail → const PurchaseResponse
- needLogin → const PurchaseResponse
- needUpdate → const PurchaseResponse
- securityError → const PurchaseResponse
- blockedApp → const PurchaseResponse
- notSupportSandbox → const PurchaseResponse
- emergencyError → const PurchaseResponse
- dataParsing → const PurchaseResponse
- signatureVerification → const PurchaseResponse
- illegalArgument → const PurchaseResponse
- undefinedCode → const PurchaseResponse
- signatureNotValidation → const PurchaseResponse
- updateOrInstall → const PurchaseResponse
- serviceDisconnected → const PurchaseResponse
- featureNotSupported → const PurchaseResponse
- serviceTimeout → const PurchaseResponse
- clientNotEnabled → const PurchaseResponse
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PurchaseResponse> - A constant List of the values in this enum, in order of their declaration.