RecurringState enum
구독 상품의 대한 구독 상태를 정의합니다. ProductType.subs 경우 상태 확인이 가능합니다. 'PurchaseData.RecurringState' 상수의 자세한 설명은 링크를 참조하세요.
Values
- notAutoProduct → const RecurringState
-
구독 상품이 아닙니다.
- recurring → const RecurringState
-
자동 결제 중
- cancel → const RecurringState
-
해지 예약 중
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
RecurringState> - A constant List of the values in this enum, in order of their declaration.